from veetility.utility_functions import UtilityFunctions
import unittest
import os


class TestBestFuzzyMatch(unittest.TestCase):

    def setUp(self):
        self.util_class = UtilityFunctions()

    def test_best_fuzzy_match_exact_match(self):
        list_1 = ["apple", "banana", "cherry"]
        list_2 = ["apple", "banana", "cherry"]
        threshold = 80
        json_name = "test_exact_match"

        expected_result = {"apple": "apple", "banana": "banana", "cherry": "cherry"}

        result = self.util_class.best_fuzzy_match(list_1, list_2, threshold, json_name)
        self.assertEqual(result, expected_result)

        # Clean up the created JSON file
        os.remove(f"JSON Files/best_match_dict_{json_name}.json")

    def test_best_fuzzy_match_no_match(self):
        list_1 = ["apple", "banana", "cherry"]
        list_2 = ["dog", "cat", "fish"]
        threshold = 80
        json_name = "test_no_match"

        expected_result = {"apple": "None", "banana": "None", "cherry": "None"}

        result = self.util_class.best_fuzzy_match(list_1, list_2, threshold, json_name)
        self.assertEqual(result, expected_result)

        # Clean up the created JSON file
        os.remove(f"JSON Files/best_match_dict_{json_name}.json")

    def test_best_fuzzy_match_null_values(self):
        list_1 = ["apple", "banana", "cherry", 'nan', 'None']
        list_2 = ["dog", "cat", "fish", 'nan', 'None']
        threshold = 80
        json_name = "test_null_values"

        expected_result = {"apple": "None", "banana": "None", "cherry": "None", "nan": "nan", "None": "None"}

        result = self.util_class.best_fuzzy_match(list_1, list_2, threshold, json_name)
        self.assertEqual(result, expected_result)

        # Clean up the created JSON file
        os.remove(f"JSON Files/best_match_dict_{json_name}.json")


if __name__ == '__main__':
    unittest.main()


# Always prefer setuptools over distutils
from setuptools import setup, find_packages

# To use a consistent encoding
from codecs import open
from os import path

# The directory containing this file
HERE = path.abspath(path.dirname(__file__))

# Get the long description from the README file
with open(path.join(HERE, 'README.md'), encoding='utf-8') as f:
    long_description = f.read()

# This call to setup() does all the work
setup(
    name="veetility",
    version="0.1.94",
    description="Demo library",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="",
    author="Vaynermedia",
    author_email="will.butler@vaynermedia.com",
    license="MIT",
    classifiers=[
        "Intended Audience :: Developers",
        "License :: OSI Approved :: MIT License",
        "Programming Language :: Python",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.6",
        "Programming Language :: Python :: 3.7",
        "Programming Language :: Python :: 3.8",
        "Programming Language :: Python :: 3.9",
        "Operating System :: OS Independent"
    ],
    packages=["veetility"],
    include_package_data=True,
    install_requires=["fuzzywuzzy", 'gspread',
                        "gspread_dataframe", "numpy",
                        "pandas", "psycopg2-binary", "regex",
                        "requests", "SQLAlchemy", "tqdm"]
)